package com.ruoyi.project.training.bccnew.service;

import java.util.List;
import com.ruoyi.project.training.bccnew.domain.TTsFtplan;

/**
 * 芳烃培训Service接口
 * 
 * @author ssy
 * @date 2024-06-13
 */
public interface ITTsFtplanService 
{
    /**
     * 查询芳烃培训
     * 
     * @param id 芳烃培训ID
     * @return 芳烃培训
     */
    public TTsFtplan selectTTsFtplanById(Long id);

    /**
     * 查询芳烃培训列表
     * 
     * @param tTsFtplan 芳烃培训
     * @return 芳烃培训集合
     */
    public List<TTsFtplan> selectTTsFtplanList(TTsFtplan tTsFtplan);
    public List<TTsFtplan> selectTTsFtplanListByNewId(TTsFtplan tTsFtplan);

    /**
     * 新增芳烃培训
     * 
     * @param tTsFtplan 芳烃培训
     * @return 结果
     */
    public int insertTTsFtplan(TTsFtplan tTsFtplan);

    /**
     * 修改芳烃培训
     * 
     * @param tTsFtplan 芳烃培训
     * @return 结果
     */
    public int updateTTsFtplan(TTsFtplan tTsFtplan);

    /**
     * 批量删除芳烃培训
     * 
     * @param ids 需要删除的芳烃培训ID
     * @return 结果
     */
    public int deleteTTsFtplanByIds(Long[] ids);

    /**
     * 删除芳烃培训信息
     * 
     * @param id 芳烃培训ID
     * @return 结果
     */
    public int deleteTTsFtplanById(Long id);
}
